@@ -1,7 +1,7 @@
 #
 # This file is part of Net-HTTP-Spore-Middleware-Header
 #
-# This software is copyright (c) 2012 by celogeek <me@celogeek.com>.
+# This software is copyright (c) 2014 by celogeek <me@celogeek.com>.
 #
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
@@ -11,7 +11,7 @@ package Net::HTTP::Spore::Middleware::Header;
 # ABSTRACT: Spore Middleware to add header on each request
 use strict;
 use warnings;
-our $VERSION = '0.02';    # VERSION
+our $VERSION = '0.03';    # VERSION
 
 use Moose;
 extends 'Net::HTTP::Spore::Middleware';
@@ -36,7 +36,7 @@ Net::HTTP::Spore::Middleware::Header - Spore Middleware to add header on each re
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -59,8 +59,7 @@ This method will add header_name:header_value in the header of each request
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-http://tasks.celogeek.com/projects/perl-modules-net-http-spore-middleware-h
-eader
+https://github.com/celogeek/Net-HTTP-Spore-Middleware-Header/issues
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -72,7 +71,7 @@ celogeek <me@celogeek.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by celogeek <me@celogeek.com>.
+This software is copyright (c) 2014 by celogeek <me@celogeek.com>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
